@@ -2,24 +2,25 @@
 options(warn=-1)
 NCAoutput<-function(sumindexR, sumindexT, R.split, T.split,keindex_ref,keindex_test,Dose, TotalData)
 {
+filepath<-getwd()
 cat("\n")
 cat("****************************************************************************\n")
-cat("* Output .txt file:                                                        *\n")
+cat(" Files have been output to the directory of                                 \n")
+cat(" ",filepath,"\n")
 cat("*--------------------------------------------------------------------------*\n")
-cat("* NCA_PK.txt:                                                              *\n")
-cat("*  -->NCA_all: Cmax, Tmax, AUC0t, AUC0inf, AUC0t/AUC0inf, ln(Cmax),        *\n")
-cat("*              ln(AUC0t),ln(AUC0inf), MRT0inf, T1/2, Vd/F, lambda, Cl/F    *\n")
-cat("* -->PK_summaries                                                          *\n")
+cat("* 1. NCA_PK.txt:                                                           *\n")
+cat("*    -->Cmax, Tmax, AUC0t, AUC0inf, AUC0t/AUC0inf, ln(Cmax), ln(AUC0t),    *\n")
+cat("*     ln(AUC0inf), MRT0inf, T1/2, Vd/F, lambda, and Cl/F                   *\n")
+cat("*    -->PK parameter summary                                               *\n")
 cat("*                                                                          *\n")
-cat("* plot.pdf                                                                 *\n")
+cat("* 2. plot.pdf: individual linear and semilog plots                         *\n")
 cat("****************************************************************************\n")
+
 #1_Cmax.txt
 zz <- file("NCA_PK.txt", open="wt")
 sink(zz)
 #############################################################################################################################   
 #NCA_output
-cat("\n<< NCA_all >>\n")
-cat("\n")
 cat("\n")
 cat("                    Reference                      \n")
 cat("---------------------------------------------------\n")
@@ -84,10 +85,10 @@ cat("---------------------------------------------------\n")
                   ClFRef[j]<-Dose/aucINF
                              
                  cat("\n") 
-                 cat("<< Summary Table--Ref_Subject:",su,">>\n")
+                 cat("<< NCA Summary Table--Subject# ",su," (Ref.)>>\n")
                  cat("--------------------------------------------------------------------------\n")
                  output<-data.frame(R.split[[j]][["subj"]],R.split[[j]][["time"]],R.split[[j]][["conc"]],auc_ref,aumc_ref )
-                 colnames(output)<-list("subj","time","conc.ref", "AUC(0~t).ref","AUMC(0~t).ref")
+                 colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
                  show(output)
                
               cat("\n<<Final Parameters>>\n")
@@ -99,12 +100,12 @@ cat("---------------------------------------------------\n")
               cat("Cl/F =",Dose/aucINF,"\n")
               cat("Vd/F =", Dose/(aucINF*ke),"\n")
               cat("T1/2 =",0.693/ke,"\n")
-              cat("AUC(0~t)=",auc_ref[length(R.split[[j]][["conc"]])],"\n") 
-              cat("AUC(0~inf) =" ,aucINF,"\n")
-              cat("AUMC(0~t)=",aumc_ref[length(R.split[[j]][["conc"]])],"\n")
-              cat("AUMC(0~inf) =" ,aumcINF,"\n")
-              cat("MRT(0~t)=",(aumc_ref[length(R.split[[j]][["conc"]])])/(auc_ref[length(R.split[[j]][["conc"]])]),"\n")
-              cat("MRT(0~inf)=",aumcINF/aucINF,"\n")
+              cat("AUC(0-t)=",auc_ref[length(R.split[[j]][["conc"]])],"\n") 
+              cat("AUC(0-inf) =" ,aucINF,"\n")
+              cat("AUMC(0-t)=",aumc_ref[length(R.split[[j]][["conc"]])],"\n")
+              cat("AUMC(0-inf) =" ,aumcINF,"\n")
+              cat("MRT(0-t)=",(aumc_ref[length(R.split[[j]][["conc"]])])/(auc_ref[length(R.split[[j]][["conc"]])]),"\n")
+              cat("MRT(0-inf)=",aumcINF/aucINF,"\n")
               cat("--------------------------------------------------------------------------\n") 
               cat("\n\n")
   }
@@ -172,10 +173,10 @@ ClFTest<-0
                   ClFTest[j]<-Dose/aucINF
                                    
                  cat("\n") 
-                 cat("<< Summary Table--Test_Subject:",su1,">>\n")
+                 cat("<< NCA Summary Table--Subject# ",su1," (Test) >>\n")
                  cat("--------------------------------------------------------------------------\n")
                  output<-data.frame(T.split[[j]][["subj"]],T.split[[j]][["time"]],T.split[[j]][["conc"]],auc_test,aumc_test )
-                 colnames(output)<-list("subj","time","conc.test", "AUC(0~t).test","AUMC(0~t).test")
+                 colnames(output)<-list("subj","time","conc", "AUC(0~t)","AUMC(0~t)")
                  show(output)
                
               cat("\n<<Final Parameters>>\n")
@@ -187,17 +188,17 @@ ClFTest<-0
               cat("Cl/F =",Dose/aucINF,"\n")
               cat("Vd/F =", Dose/(aucINF*ke1),"\n")
               cat("T1/2 =",0.693/ke1,"\n")
-              cat("AUC(0~t)=",auc_test[length(T.split[[j]][["conc"]])],"\n") 
-              cat("AUC(0~inf) =" ,aucINF,"\n")
-              cat("AUMC(0~t)=",aumc_test[length(T.split[[j]][["conc"]])],"\n")
-              cat("AUMC(0~inf) =" ,aumcINF,"\n")
-              cat("MRT(0~t)=",(aumc_test[length(T.split[[j]][["conc"]])])/(auc_test[length(T.split[[j]][["conc"]])]),"\n")
-              cat("MRT(0~inf)=",aumcINF/aucINF,"\n")
+              cat("AUC(0-t)=",auc_test[length(T.split[[j]][["conc"]])],"\n") 
+              cat("AUC(0-inf) =" ,aucINF,"\n")
+              cat("AUMC(0-t)=",aumc_test[length(T.split[[j]][["conc"]])],"\n")
+              cat("AUMC(0-inf) =" ,aumcINF,"\n")
+              cat("MRT(0-t)=",(aumc_test[length(T.split[[j]][["conc"]])])/(auc_test[length(T.split[[j]][["conc"]])]),"\n")
+              cat("MRT(0-inf)=",aumcINF/aucINF,"\n")
               cat("--------------------------------------------------------------------------\n") 
               cat("\n\n")
   }
 
-cat("\n<< PK_summaries >>\n")
+cat("\n<< PK parameter summaries >>\n")
 cat("\n")
 cat("\n")
 cat("                         Cmax                     \n")
@@ -468,9 +469,6 @@ zz <- file("Statistical_summaries.txt", open="wt")
 sink(zz)
 cat("\n")
 cat("\n")
-cat("\n<< Statistical summaries >>\n")
-cat("\n")
-cat("\n")
 cat("         Statistical Summaries for Bioequivalence Study (n=",L1+L2,")\n")
 cat("--------------------------------------------------------------------------\n")
 cat("\n")
