@@ -2,6 +2,10 @@
 go<-function()
 {
 options(warn=-1)
+if (noquote(unlist(format(.Platform)))[1] == "unix") {
+        windows <<- function(record) {
+        }
+     }   
 cat("\n")
   file.menu <- c("Sample size estimation for ABE ",
                  "Noncompartmental Analysis (NCA)",
